ztplnMLE fits the Zero-truncated Poisson lognormal distribution to data and
estimates parameters mean mu and standard deviation sig in the lognormal
distribution
ztplnMLE(
n,
lower_mu = 0,
upper_mu = log(max(n)),
lower_sig = 0.001,
upper_sig = 10,
type1 = TRUE
)An integer code. 0 indicates successful convergence.
Number of iterations performed.
A character string giving any additional information returned by the optimizer, or NULL. For details, see PORT documentation.
Number of objective function and gradient function evaluations
Maximum likelihood estimates of mu
Maximum likelihood estimates of sig
loglikelihood
a integer vector of counts
numeric values of lower and upper bounds for mean of the variables's natrual logarithm.
numeric values of lower and upper bounds for standard deviatoin of the variables's natrual logarithm
logical; if TRUE, Use type 1 ztpln else use type 2.
The function searches the maximum likelihood estimates of mean mu and
standard deviation sig using the optimization procedures in
nlminb.
y <- rztpln(100, 3, 2)
ztplnMLE(y)
Run the code above in your browser using DataLab