ztplnmMLE fits the Zero-truncated Poisson lognormal mixture distribution
to data and estimates parameters mean mu, standard deviation sig and
mixture weight theta in the lognormal distribution.
ztplnmMLE(
n,
K = 2,
lower_mu = rep(0, K),
upper_mu = rep(log(max(n)), K),
lower_sig = rep(0.001, K),
upper_sig = rep(10, K),
lower_theta = rep(0.001, K),
upper_theta = rep(0.999, K),
type1 = TRUE,
message = FALSE
)An integer code. 0 indicates successful convergence.
Number of iterations performed.
A character string giving any additional information returned by the optimizer, or NULL. For details, see PORT documentation.
Number of objective function and gradient function evaluations
Maximum likelihood estimates of mu
Maximum likelihood estimates of sig
Maximum likelihood estimates of theta
loglikelihood
a vector of counts
number of components
numeric values of lower and upper bounds for mean of the variables's natural logarithm.
numeric values of lower and upper bounds for standard deviation of the variables's natural logarithm
numeric values of lower and upper bounds for mixture weights.
logical; if TRUE, Use type 1 ztpln else use type 2.
mean of lognormal distribution in sample 3.
The function searches the maximum likelihood estimators of mean vector mu,
standard deviation vector sig and mixture weight vector theta using the
optimization procedures in nlminb.
y <- rztplnm(100, c(1, 10), c(2, 1), c(0.2, 0.8))
ztplnmMLE(y)
Run the code above in your browser using DataLab